summaryrefslogtreecommitdiffstats
path: root/packages/SystemUI/src/com/android/systemui/recents
diff options
context:
space:
mode:
authorWinson Chung <winsonc@google.com>2014-09-09 17:54:51 +0200
committerWinson Chung <winsonc@google.com>2014-09-09 22:48:19 +0000
commit3aa9c221c0d092b927628be6a7ba371028cebe79 (patch)
treea1454c02084007346c5278d4f8fb79f45d97a259 /packages/SystemUI/src/com/android/systemui/recents
parent7937fdb34133803ff8dcc67f7f1c0b6928598e62 (diff)
downloadframeworks_base-3aa9c221c0d092b927628be6a7ba371028cebe79.zip
frameworks_base-3aa9c221c0d092b927628be6a7ba371028cebe79.tar.gz
frameworks_base-3aa9c221c0d092b927628be6a7ba371028cebe79.tar.bz2
Adding task switching animation xmls for further tweaking. (Bug 16656169)
Change-Id: I472116cb3d86a3f90a935b2a3ac058ffc2ac1b5d
Diffstat (limited to 'packages/SystemUI/src/com/android/systemui/recents')
-rw-r--r--packages/SystemUI/src/com/android/systemui/recents/AlternateRecentsComponent.java14
1 files changed, 11 insertions, 3 deletions
diff --git a/packages/SystemUI/src/com/android/systemui/recents/AlternateRecentsComponent.java b/packages/SystemUI/src/com/android/systemui/recents/AlternateRecentsComponent.java
index f23f9f2..f65621e 100644
--- a/packages/SystemUI/src/com/android/systemui/recents/AlternateRecentsComponent.java
+++ b/packages/SystemUI/src/com/android/systemui/recents/AlternateRecentsComponent.java
@@ -190,10 +190,14 @@ public class AlternateRecentsComponent implements ActivityOptions.OnAnimationSta
Task.TaskKey toTaskKey;
if (showNextTask) {
toTaskKey = group.getNextTaskInGroup(task);
- // XXX: We will actually set the appropriate launch animations here
+ launchOpts = ActivityOptions.makeCustomAnimation(mContext,
+ R.anim.recents_launch_next_affiliated_task_target,
+ R.anim.recents_launch_next_affiliated_task_source);
} else {
toTaskKey = group.getPrevTaskInGroup(task);
- // XXX: We will actually set the appropriate launch animations here
+ launchOpts = ActivityOptions.makeCustomAnimation(mContext,
+ R.anim.recents_launch_prev_affiliated_task_target,
+ R.anim.recents_launch_prev_affiliated_task_source);
}
if (toTaskKey != null) {
toTask = stack.findTaskWithId(toTaskKey.id);
@@ -204,7 +208,11 @@ public class AlternateRecentsComponent implements ActivityOptions.OnAnimationSta
// Return early if there is no next task
if (toTask == null) {
- // XXX: We will actually show a bounce animation here
+ if (showNextTask) {
+ // XXX: Show the next-task bounce animation
+ } else {
+ // XXX: Show the prev-task bounce animation
+ }
return;
}